*==============================================================================
* Program:				NewObj
* Purpose:				Create an object from a specified class
* Author:				Doug Hennig
* Copyright:			(c) 1997 Stonefield Systems Group Inc.
* Last revision:		04/14/97
* Parameters:			tcClass - the name of the class to instantiate,
*							optionally preceded by the name of the VCX and a
*							comma (eg. SFQuery,SFGetFilter would create an
*							SFGetFilter object from SFQUERY.VCX)
*						tuParm1 - an optional parameter to pass to the new
*							object's Init method
*						tuParm2 - an optional parameter to pass to the new
*							object's Init method
*						tuParm3 - an optional parameter to pass to the new
*							object's Init method
*						tuParm4 - an optional parameter to pass to the new
*							object's Init method
* Returns:				the return value from CREATEOBJECT() (usually an object
*							reference but it could also be .F. if the object
*							failed to instantiate)
* Environment in:		if the VCX is specified in tcClass, it must be in the
*							VFP path
*						if the VCX isn't specified, it must already be opened
*							with SET CLASSLIB TO
* Environment out:		the object may have been instantiated
*==============================================================================

lparameters tcClass, ;
	tuParm1, ;
	tuParm2, ;
	tuParm3, ;
	tuParm4
local lcClass, ;
	lcLibrary, ;
	lnPos, ;
	loObject

* If the specified class to create includes the name of the VCX the class is
* in, parse that out and SET CLASSLIB to it if necessary.

lcClass   = upper(tcClass)
lcLibrary = ''
if ',' $ lcClass and left(lcClass, 1) <> ','
	lnPos     = at(',', lcClass)
	lcLibrary = alltrim(left(lcClass, lnPos - 1))
	lcClass   = alltrim(substr(lcClass, lnPos + 1))
	if lcLibrary $ upper(set('CLASSLIB'))
		lcLibrary = ''
	else
		set classlib to (lcLibrary) additive
	endif lcLibrary $ upper(set('CLASSLIB'))
endif ',' $ lcClass ...

* Create the object.

do case
	case pcount() = 1
		loObject = createobject(lcClass)
	case pcount() = 2
		loObject = createobject(lcClass, @tuParm1)
	case pcount() = 3
		loObject = createobject(lcClass, @tuParm1, @tuParm2)
	case pcount() = 4
		loObject = createobject(lcClass, @tuParm1, @tuParm2, @tuParm3)
	case pcount() = 5
		loObject = createobject(lcClass, @tuParm1, @tuParm2, @tuParm3, ;
			@tuParm4)
endcase

* Release the library if we opened it (and it's still open) and return a
* reference to the object we created.

if not empty(lcLibrary) and lcLibrary $ set('CLASSLIB')
	release classlib (lcLibrary)
endif not empty(lcLibrary) ...
return loObject
